# PaddleJsConverter

## Installation

System Requirements:

* paddlepaddle >= 2.0.0
* paddlelite == 2.7.1
* Python3： 3.5.1+ / 3.6 / 3.7
* Python2： 2.7.15+

#### Install PaddleJsConverter

```shell
pip install paddlejsconverter

# or
pip3 install paddlejsconverter
```


## Usage

```shell
paddlejsconverter --modelPath=user_model_path --paramPath=user_model_params_path --outputDir=model_saved_path
```
